==> zzyj-outputvalcount-impl-3.0.0-20240611.234607-297-sources.jar: com/ejianc/business/worklog/service/impl/OrgIndexSubmitBpmServiceImpl.java <==
package com.ejianc.business.worklog.service.impl;

import com.ejianc.business.worklog.bean.OrgIndexConfirmEntity;
import com.ejianc.business.worklog.bean.OrgIndexSubmitEntity;
import com.ejianc.business.worklog.service.IOrgIndexConfirmService;
import com.ejianc.business.worklog.service.IOrgIndexSubmitService;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

@Service("orgIndexSubmit") 
public class OrgIndexSubmitBpmServiceImpl implements ICommonBusinessService {

	@Autowired
	private IOrgIndexConfirmService indexConfirmService;

	@Autowired
	private IOrgIndexSubmitService indexSubmitService;


	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		OrgIndexSubmitEntity indexSubmitEntity = indexSubmitService.selectById(billId);
		OrgIndexConfirmEntity indexConfirmEntity = new OrgIndexConfirmEntity();

		indexConfirmEntity.setDepartmentId(indexSubmitEntity.getDepartmentId());
		indexConfirmEntity.setDepartmentName(indexSubmitEntity.getDepartmentName());
		indexConfirmEntity.setManageType(indexSubmitEntity.getManageType());
		indexConfirmEntity.setIndexSource(indexSubmitEntity.getIndexSource());
		indexConfirmEntity.setIndexRemark(indexSubmitEntity.getIndexRemark());
		indexConfirmEntity.setIndexName(indexSubmitEntity.getIndexName());
		indexConfirmEntity.setIndexType(indexSubmitEntity.getIndexType());
		indexConfirmEntity.setIndexFormula(indexSubmitEntity.getIndexFormula());
		indexConfirmEntity.setIndexFrom(indexSubmitEntity.getIndexFrom());
		indexConfirmEntity.setIndexRule(indexSubmitEntity.getIndexRule());
		indexConfirmEntity.setIndexYear(indexSubmitEntity.getIndexYear());
		indexConfirmEntity.setCreateUserName(indexSubmitEntity.getCreateUserName());
		indexConfirmEntity.setSourceId(indexSubmitEntity.getId());

		indexConfirmService.saveOrUpdate(indexConfirmEntity);

		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}

==> zzyj-outputvalcount-impl-3.0.0-20250115.041857-333-sources.jar: com/ejianc/business/worklog/service/impl/OrgIndexSubmitBpmServiceImpl.java <==
package com.ejianc.business.worklog.service.impl;

import com.ejianc.business.worklog.bean.OrgIndexConfirmEntity;
import com.ejianc.business.worklog.bean.OrgIndexSubmitEntity;
import com.ejianc.business.worklog.service.IOrgIndexConfirmService;
import com.ejianc.business.worklog.service.IOrgIndexSubmitService;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

@Service("orgIndexSubmit") 
public class OrgIndexSubmitBpmServiceImpl implements ICommonBusinessService {

	@Autowired
	private IOrgIndexConfirmService indexConfirmService;

	@Autowired
	private IOrgIndexSubmitService indexSubmitService;


	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		//指标确认通过审批流，不再推送新表单
//		OrgIndexSubmitEntity indexSubmitEntity = indexSubmitService.selectById(billId);
//		OrgIndexConfirmEntity indexConfirmEntity = new OrgIndexConfirmEntity();
//
//		indexConfirmEntity.setDepartmentId(indexSubmitEntity.getDepartmentId());
//		indexConfirmEntity.setDepartmentName(indexSubmitEntity.getDepartmentName());
//		indexConfirmEntity.setManageType(indexSubmitEntity.getManageType());
//		indexConfirmEntity.setIndexSource(indexSubmitEntity.getIndexSource());
//		indexConfirmEntity.setIndexRemark(indexSubmitEntity.getIndexRemark());
//		indexConfirmEntity.setIndexName(indexSubmitEntity.getIndexName());
//		indexConfirmEntity.setIndexType(indexSubmitEntity.getIndexType());
//		indexConfirmEntity.setIndexFormula(indexSubmitEntity.getIndexFormula());
//		indexConfirmEntity.setIndexFrom(indexSubmitEntity.getIndexFrom());
//		indexConfirmEntity.setIndexRule(indexSubmitEntity.getIndexRule());
//		indexConfirmEntity.setIndexYear(indexSubmitEntity.getIndexYear());
//		indexConfirmEntity.setCreateUserName(indexSubmitEntity.getCreateUserName());
//		indexConfirmEntity.setSourceId(indexSubmitEntity.getId());
//
//		indexConfirmService.saveOrUpdate(indexConfirmEntity);

		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}
